@@ -2,13 +2,13 @@ package Hypernova;
 use strict;
 use warnings;
 
-our $VERSION = 0.01; # TRIAL
+our $VERSION = 0.02; # TRIAL
 
 =pod
 
 =head1 NAME
 
-Hypernova - Perl Hypernova Client (for rendering React components)j
+Hypernova - Perl Hypernova Client (for rendering React components)
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ Hypernova-PHP: L<https://github.com/wayfair/hypernova-php>
 
 =head1 AUTHOR
 	
-James Wright <jameswright.vegas@gmail.com>
+James Wright <jwright@cpan.org>
 
 =head1 COPYRIGHT
 
